Index: /trunk/src/VBox/Devices/Network/testcase/tstIntNet-1.cpp
===================================================================
--- /trunk/src/VBox/Devices/Network/testcase/tstIntNet-1.cpp	(revision 19923)
+++ /trunk/src/VBox/Devices/Network/testcase/tstIntNet-1.cpp	(revision 19924)
@@ -846,8 +846,8 @@
 
     char szPath[RTPATH_MAX];
-    rc = RTPathProgram(szPath, sizeof(szPath) - sizeof("/../VMMR0.r0"));
+    rc = RTPathExecDir(szPath, sizeof(szPath) - sizeof("/../VMMR0.r0"));
     if (RT_FAILURE(rc))
     {
-        RTPrintf("tstIntNet-1: RTPathProgram -> %Rrc\n", rc);
+        RTPrintf("tstIntNet-1: RTPathExecDir -> %Rrc\n", rc);
         return 1;
     }
Index: /trunk/src/VBox/Frontends/VBoxFB/VBoxFB.cpp
===================================================================
--- /trunk/src/VBox/Frontends/VBoxFB/VBoxFB.cpp	(revision 19923)
+++ /trunk/src/VBox/Frontends/VBoxFB/VBoxFB.cpp	(revision 19924)
@@ -137,5 +137,5 @@
     // get the path to the executable
     char appPath [RTPATH_MAX];
-    RTPathProgram (appPath, RTPATH_MAX);
+    RTPathExecDir (appPath, RTPATH_MAX);
 
     nsCOMPtr<nsIFile> nsAppPath;
Index: /trunk/src/VBox/HostDrivers/Support/SUPLibInternal.h
===================================================================
--- /trunk/src/VBox/HostDrivers/Support/SUPLibInternal.h	(revision 19923)
+++ /trunk/src/VBox/HostDrivers/Support/SUPLibInternal.h	(revision 19924)
@@ -79,5 +79,5 @@
 # define supR3HardenedPathSharedLibs       supR3HardenedStaticPathSharedLibs
 # define supR3HardenedPathAppDocs          supR3HardenedStaticPathAppDocs
-# define supR3HardenedPathProgram          supR3HardenedStaticPathProgram
+# define supR3HardenedPathExecDir          supR3HardenedStaticPathExecDir
 # define supR3HardenedPathFilename         supR3HardenedStaticPathFilename
 # define supR3HardenedFatalV               supR3HardenedStaticFatalV
@@ -274,6 +274,6 @@
 /** @copydoc RTPathAppDocs */
 DECLHIDDEN(int)    supR3HardenedPathAppDocs(char *pszPath, size_t cchPath);
-/** @copydoc RTPathProgram */
-DECLHIDDEN(int)    supR3HardenedPathProgram(char *pszPath, size_t cchPath);
+/** @copydoc RTPathExecDir */
+DECLHIDDEN(int)    supR3HardenedPathExecDir(char *pszPath, size_t cchPath);
 /** @copydoc RTPathFilename */
 DECLHIDDEN(char *) supR3HardenedPathFilename(const char *pszPath);
Index: /trunk/src/VBox/HostDrivers/Support/SUPR3HardenedIPRT.cpp
===================================================================
--- /trunk/src/VBox/HostDrivers/Support/SUPR3HardenedIPRT.cpp	(revision 19923)
+++ /trunk/src/VBox/HostDrivers/Support/SUPR3HardenedIPRT.cpp	(revision 19924)
@@ -91,9 +91,9 @@
 
 /**
- * @copydoc RTPathProgram
+ * @copydoc RTPathExecDir
  */
-DECLHIDDEN(int) supR3HardenedPathProgram(char *pszPath, size_t cchPath)
+DECLHIDDEN(int) supR3HardenedPathExecDir(char *pszPath, size_t cchPath)
 {
-    return RTPathProgram(pszPath, cchPath);
+    return RTPathExecDir(pszPath, cchPath);
 }
 
Index: /trunk/src/VBox/HostDrivers/Support/SUPR3HardenedMain.cpp
===================================================================
--- /trunk/src/VBox/HostDrivers/Support/SUPR3HardenedMain.cpp	(revision 19923)
+++ /trunk/src/VBox/HostDrivers/Support/SUPR3HardenedMain.cpp	(revision 19924)
@@ -235,5 +235,5 @@
 
 #else
-    return supR3HardenedPathProgram(pszPath, cchPath);
+    return supR3HardenedPathExecDir(pszPath, cchPath);
 #endif
 }
@@ -255,5 +255,5 @@
 
 #else
-    return supR3HardenedPathProgram(pszPath, cchPath);
+    return supR3HardenedPathExecDir(pszPath, cchPath);
 #endif
 }
@@ -275,5 +275,5 @@
 
 #else
-    return supR3HardenedPathProgram(pszPath, cchPath);
+    return supR3HardenedPathExecDir(pszPath, cchPath);
 #endif
 }
@@ -295,5 +295,5 @@
 
 #else
-    return supR3HardenedPathProgram(pszPath, cchPath);
+    return supR3HardenedPathExecDir(pszPath, cchPath);
 #endif
 }
@@ -329,5 +329,5 @@
 # endif
     if (cchLink < 0 || cchLink == sizeof(g_szSupLibHardenedExePath) - 1)
-        supR3HardenedFatal("supR3HardenedPathProgram: couldn't read \"%s\", errno=%d cchLink=%d\n",
+        supR3HardenedFatal("supR3HardenedExecDir: couldn't read \"%s\", errno=%d cchLink=%d\n",
                             g_szSupLibHardenedExePath, errno, cchLink);
     g_szSupLibHardenedExePath[cchLink] = '\0';
@@ -339,8 +339,8 @@
     const char *pszImageName = _dyld_get_image_name(0);
     if (!pszImageName)
-        supR3HardenedFatal("supR3HardenedPathProgram: _dyld_get_image_name(0) failed\n");
+        supR3HardenedFatal("supR3HardenedExecDir: _dyld_get_image_name(0) failed\n");
     size_t cchImageName = strlen(pszImageName);
     if (!cchImageName || cchImageName >= sizeof(g_szSupLibHardenedExePath))
-        supR3HardenedFatal("supR3HardenedPathProgram: _dyld_get_image_name(0) failed, cchImageName=%d\n", cchImageName);
+        supR3HardenedFatal("supR3HardenedExecDir: _dyld_get_image_name(0) failed, cchImageName=%d\n", cchImageName);
     memcpy(g_szSupLibHardenedExePath, pszImageName, cchImageName + 1);
 
@@ -348,5 +348,5 @@
     HMODULE hExe = GetModuleHandle(NULL);
     if (!GetModuleFileName(hExe, &g_szSupLibHardenedExePath[0], sizeof(g_szSupLibHardenedExePath)))
-        supR3HardenedFatal("supR3HardenedPathProgram: GetModuleFileName failed, rc=%d\n", GetLastError());
+        supR3HardenedFatal("supR3HardenedExecDir: GetModuleFileName failed, rc=%d\n", GetLastError());
 #else
 # error needs porting.
@@ -381,7 +381,7 @@
 
 /**
- * @copydoc RTPathProgram
- */
-DECLHIDDEN(int) supR3HardenedPathProgram(char *pszPath, size_t cchPath)
+ * @copydoc RTPathExecDir
+ */
+DECLHIDDEN(int) supR3HardenedPathExecDir(char *pszPath, size_t cchPath)
 {
     /*
@@ -401,5 +401,5 @@
     }
 
-    supR3HardenedFatal("supR3HardenedPathProgram: Buffer too small (%u < %u)\n", cchPath, cch);
+    supR3HardenedFatal("supR3HardenedPathExecDir: Buffer too small (%u < %u)\n", cchPath, cch);
     return VERR_BUFFER_OVERFLOW;
 }
Index: /trunk/src/VBox/HostDrivers/Support/SUPR3HardenedVerify.cpp
===================================================================
--- /trunk/src/VBox/HostDrivers/Support/SUPR3HardenedVerify.cpp	(revision 19923)
+++ /trunk/src/VBox/HostDrivers/Support/SUPR3HardenedVerify.cpp	(revision 19924)
@@ -216,5 +216,5 @@
         case kSupID_AppBin: /** @todo fix this AppBin crap (uncertain wtf some binaries actually are installed). */
         case kSupID_Bin:
-            rc = supR3HardenedPathProgram(pszDst, cchDst);
+            rc = supR3HardenedPathExecDir(pszDst, cchDst);
             break;
         case kSupID_SharedLib:
@@ -678,5 +678,5 @@
 
                 char szFilename[RTPATH_MAX];
-                int rc2 = supR3HardenedPathProgram(szFilename, sizeof(szFilename) - cchProgName - sizeof(SUPLIB_EXE_SUFF));
+                int rc2 = supR3HardenedPathExecDir(szFilename, sizeof(szFilename) - cchProgName - sizeof(SUPLIB_EXE_SUFF));
                 if (RT_SUCCESS(rc2))
                 {
Index: /trunk/src/VBox/HostDrivers/Support/win/SUPLib-win.cpp
===================================================================
--- /trunk/src/VBox/HostDrivers/Support/win/SUPLib-win.cpp	(revision 19923)
+++ /trunk/src/VBox/HostDrivers/Support/win/SUPLib-win.cpp	(revision 19924)
@@ -182,5 +182,5 @@
     {
         char szDriver[RTPATH_MAX];
-        int rc = RTPathProgram(szDriver, sizeof(szDriver) - sizeof("\\VBoxDrv.sys"));
+        int rc = RTPathExecDir(szDriver, sizeof(szDriver) - sizeof("\\VBoxDrv.sys"));
         if (RT_SUCCESS(rc))
         {
@@ -333,5 +333,5 @@
         {
             char szDriver[RTPATH_MAX];
-            int rc = RTPathProgram(szDriver, sizeof(szDriver) - sizeof("\\VBoxDrv.sys"));
+            int rc = RTPathExecDir(szDriver, sizeof(szDriver) - sizeof("\\VBoxDrv.sys"));
             if (RT_SUCCESS(rc))
             {
Index: /trunk/src/VBox/Main/generic/NetIf-generic.cpp
===================================================================
--- /trunk/src/VBox/Main/generic/NetIf-generic.cpp	(revision 19923)
+++ /trunk/src/VBox/Main/generic/NetIf-generic.cpp	(revision 19924)
@@ -43,5 +43,5 @@
 
     char szAdpCtl[RTPATH_MAX];
-    int rc = RTPathProgram(szAdpCtl, sizeof(szAdpCtl) - sizeof("/" VBOXNETADPCTL_NAME));
+    int rc = RTPathExecDir(szAdpCtl, sizeof(szAdpCtl) - sizeof("/" VBOXNETADPCTL_NAME));
     if (RT_FAILURE(rc))
     {
@@ -151,5 +151,5 @@
 
             char szAdpCtl[RTPATH_MAX];
-            int rc = RTPathProgram(szAdpCtl, sizeof(szAdpCtl) - sizeof("/" VBOXNETADPCTL_NAME " add"));
+            int rc = RTPathExecDir(szAdpCtl, sizeof(szAdpCtl) - sizeof("/" VBOXNETADPCTL_NAME " add"));
             if (RT_FAILURE(rc))
             {
Index: /trunk/src/VBox/NetworkServices/DHCP/VBoxNetDHCP.cpp
===================================================================
--- /trunk/src/VBox/NetworkServices/DHCP/VBoxNetDHCP.cpp	(revision 19923)
+++ /trunk/src/VBox/NetworkServices/DHCP/VBoxNetDHCP.cpp	(revision 19924)
@@ -872,5 +872,5 @@
 
     char szPath[RTPATH_MAX];
-    rc = RTPathProgram(szPath, sizeof(szPath) - sizeof("/VMMR0.r0"));
+    rc = RTPathExecDir(szPath, sizeof(szPath) - sizeof("/VMMR0.r0"));
     if (RT_FAILURE(rc))
     {
Index: /trunk/src/VBox/Runtime/r3/init.cpp
===================================================================
--- /trunk/src/VBox/Runtime/r3/init.cpp	(revision 19923)
+++ /trunk/src/VBox/Runtime/r3/init.cpp	(revision 19924)
@@ -78,5 +78,5 @@
 
 /** The process path.
- * This is used by RTPathProgram and RTProcGetExecutableName and set by rtProcInitName. */
+ * This is used by RTPathExecDir and RTProcGetExecutableName and set by rtProcInitName. */
 char        g_szrtProcExePath[RTPATH_MAX];
 /** The length of g_szrtProcExePath. */
Index: /trunk/src/VBox/Runtime/testcase/tstLdr-4.cpp
===================================================================
--- /trunk/src/VBox/Runtime/testcase/tstLdr-4.cpp	(revision 19923)
+++ /trunk/src/VBox/Runtime/testcase/tstLdr-4.cpp	(revision 19924)
@@ -236,5 +236,5 @@
      */
     char szPath[RTPATH_MAX];
-    rc = RTPathProgram(szPath, sizeof(szPath) - sizeof("/tstLdrObjR0.r0"));
+    rc = RTPathExecDir(szPath, sizeof(szPath) - sizeof("/tstLdrObjR0.r0"));
     if (RT_SUCCESS(rc))
     {
@@ -245,5 +245,5 @@
     else
     {
-        RTPrintf("tstLdr-4: RTPathProgram -> %Rrc\n", rc);
+        RTPrintf("tstLdr-4: RTPathExecDir -> %Rrc\n", rc);
         cErrors++;
     }
Index: /trunk/src/VBox/VMM/PDMLdr.cpp
===================================================================
--- /trunk/src/VBox/VMM/PDMLdr.cpp	(revision 19923)
+++ /trunk/src/VBox/VMM/PDMLdr.cpp	(revision 19924)
@@ -978,5 +978,5 @@
     if (!RT_SUCCESS(rc))
     {
-        AssertMsgFailed(("RTPathProgram(,%d) failed rc=%d!\n", sizeof(szPath), rc));
+        AssertMsgFailed(("RTPath[SharedLibs|AppPrivateArch](,%d) failed rc=%d!\n", sizeof(szPath), rc));
         return NULL;
     }
Index: /trunk/src/testcase/tstRunTestcases.cpp
===================================================================
--- /trunk/src/testcase/tstRunTestcases.cpp	(revision 19923)
+++ /trunk/src/testcase/tstRunTestcases.cpp	(revision 19924)
@@ -264,8 +264,8 @@
     {
         char szPath[RTPATH_MAX];
-        int rc = RTPathProgram(szPath, sizeof(szPath) - sizeof("/.."));
+        int rc = RTPathExecDir(szPath, sizeof(szPath) - sizeof("/.."));
         if (RT_FAILURE(rc))
         {
-            RTPrintf("fatal error: RTPathProgram -> %Rrc\n", rc);
+            RTPrintf("fatal error: RTPathExecDir -> %Rrc\n", rc);
             return 1;
         }

Index: /trunk/include/iprt/path.h
===================================================================
--- /trunk/include/iprt/path.h	(revision 19923)
+++ /trunk/include/iprt/path.h	(revision 19924)
@@ -346,5 +346,5 @@
 
 /**
- * Gets the program path.
+ * Gets the path to the directory containing the executable.
  *
  * @returns iprt status code.
@@ -352,5 +352,5 @@
  * @param   cchPath     Buffer size in bytes.
  */
-RTDECL(int) RTPathProgram(char *pszPath, size_t cchPath);
+RTDECL(int) RTPathExecDir(char *pszPath, size_t cchPath);
 
 /**
@@ -364,11 +364,12 @@
 
 /**
- * Gets the directory of shared libraries. This is not the same as
- * RTPathAppPrivateArch() as Linux depends all shared libraries in
- * a common global directory where ld.so can found them.
+ * Gets the directory of shared libraries.
+ *
+ * This is not the same as RTPathAppPrivateArch() as Linux depends all shared
+ * libraries in a common global directory where ld.so can found them.
  *
  * Linux:    /usr/lib
  * Windows:  @<program files directory@>/@<application@>
  * Old path: same as RTPathProgram()
  *
  * @returns iprt status code.
@@ -384,5 +385,5 @@
  * Linux:    /usr/shared/@<application@>
  * Windows:  @<program files directory@>/@<application@>
  * Old path: same as RTPathProgram()
  *
  * @returns iprt status code.
@@ -398,5 +399,5 @@
  * Linux:    /usr/lib/@<application@>
  * Windows:  @<program files directory@>/@<application@>
  * Old path: same as RTPathProgram()
  *
  * @returns iprt status code.
@@ -411,5 +412,5 @@
  * Linux:    /usr/share/doc/@<application@>
  * Windows:  @<program files directory@>/@<application@>
  * Old path: same as RTPathProgram()
  *
  * @returns iprt status code.
@@ -364,11 +364,12 @@
  * Linux:    /usr/lib
  * Windows:  @<program files directory@>/@<application@>
- * Old path: same as RTPathProgram()
+ * Old path: same as RTPathExecDir()
  *
  * @returns iprt status code.
@@ -384,5 +385,5 @@
  * Linux:    /usr/shared/@<application@>
  * Windows:  @<program files directory@>/@<application@>
- * Old path: same as RTPathProgram()
+ * Old path: same as RTPathExecDir()
  *
  * @returns iprt status code.
@@ -398,5 +399,5 @@
  * Linux:    /usr/lib/@<application@>
  * Windows:  @<program files directory@>/@<application@>
- * Old path: same as RTPathProgram()
+ * Old path: same as RTPathExecDir()
  *
  * @returns iprt status code.
@@ -411,5 +412,5 @@
  * Linux:    /usr/share/doc/@<application@>
  * Windows:  @<program files directory@>/@<application@>
- * Old path: same as RTPathProgram()
+ * Old path: same as RTPathExecDir()
  *
  * @returns iprt status code.
Index: /trunk/src/VBox/Runtime/r3/path.cpp
===================================================================
--- /trunk/src/VBox/Runtime/r3/path.cpp	(revision 19923)
+++ /trunk/src/VBox/Runtime/r3/path.cpp	(revision 19924)
@@ -666,5 +666,5 @@
 #ifndef RT_MINI
 
-RTDECL(int) RTPathProgram(char *pszPath, size_t cchPath)
+RTDECL(int) RTPathExecDir(char *pszPath, size_t cchPath)
 {
     AssertReturn(g_szrtProcExePath[0], VERR_WRONG_ORDER);
@@ -692,5 +692,5 @@
  * Linux:    /usr/shared/@<application@>
  * Windows:  @<program files directory@>/@<application@>
  * Old path: same as RTPathProgram()
  *
  */
@@ -712,5 +712,5 @@
     return rc;
 #else
-    return RTPathProgram(pszPath, cchPath);
+    return RTPathExecDir(pszPath, cchPath);
 #endif
 }
@@ -723,5 +723,5 @@
  * Linux:    /usr/lib/@<application@>
  * Windows:  @<program files directory@>/@<application@>
  * Old path: same as RTPathProgram()
  *
  * @returns iprt status code.
@@ -746,5 +746,5 @@
     return rc;
 #else
-    return RTPathProgram(pszPath, cchPath);
+    return RTPathExecDir(pszPath, cchPath);
 #endif
 }
@@ -758,5 +758,5 @@
  * Linux:    /usr/lib
  * Windows:  @<program files directory@>/@<application@>
  * Old path: same as RTPathProgram()
  *
  * @returns iprt status code.
@@ -781,5 +781,5 @@
     return rc;
 #else
-    return RTPathProgram(pszPath, cchPath);
+    return RTPathExecDir(pszPath, cchPath);
 #endif
 }
@@ -791,5 +791,5 @@
  * Linux:    /usr/share/doc/@<application@>
  * Windows:  @<program files directory@>/@<application@>
  * Old path: same as RTPathProgram()
  *
  * @returns iprt status code.
@@ -814,5 +814,5 @@
     return rc;
 #else
-    return RTPathProgram(pszPath, cchPath);
+    return RTPathExecDir(pszPath, cchPath);
 #endif
 }
@@ -692,5 +692,5 @@
  * Linux:    /usr/shared/@<application@>
  * Windows:  @<program files directory@>/@<application@>
- * Old path: same as RTPathProgram()
+ * Old path: same as RTPathExecDir()
  *
  */
@@ -723,5 +723,5 @@
  * Linux:    /usr/lib/@<application@>
  * Windows:  @<program files directory@>/@<application@>
- * Old path: same as RTPathProgram()
+ * Old path: same as RTPathExecDir()
  *
  * @returns iprt status code.
@@ -758,5 +758,5 @@
  * Linux:    /usr/lib
  * Windows:  @<program files directory@>/@<application@>
- * Old path: same as RTPathProgram()
+ * Old path: same as RTPathExecDir()
  *
  * @returns iprt status code.
@@ -791,5 +791,5 @@
  * Linux:    /usr/share/doc/@<application@>
  * Windows:  @<program files directory@>/@<application@>
- * Old path: same as RTPathProgram()
+ * Old path: same as RTPathExecDir()
  *
  * @returns iprt status code.
Index: /trunk/src/VBox/Runtime/testcase/tstPath.cpp
===================================================================
--- /trunk/src/VBox/Runtime/testcase/tstPath.cpp	(revision 19923)
+++ /trunk/src/VBox/Runtime/testcase/tstPath.cpp	(revision 19924)
@@ -63,10 +63,10 @@
 
     /*
      * RTPathProgram, RTPathUserHome and RTProcGetExecutableName.
      */
     char szPath[RTPATH_MAX];
-    CHECK_RC(RTPathProgram(szPath, sizeof(szPath)));
+    CHECK_RC(RTPathExecDir(szPath, sizeof(szPath)));
     if (RT_SUCCESS(rc))
-        RTPrintf("Program={%s}\n", szPath);
+        RTPrintf("ExecDir={%s}\n", szPath);
     CHECK_RC(RTPathUserHome(szPath, sizeof(szPath)));
     if (RT_SUCCESS(rc))
@@ -63,10 +63,10 @@
 
     /*
-     * RTPathProgram, RTPathUserHome and RTProcGetExecutableName.
+     * RTPathExecDir, RTPathUserHome and RTProcGetExecutableName.
      */
     char szPath[RTPATH_MAX];